WSLPluginAPI_OnDistributionStopping

Type Alias WSLPluginAPI_OnDistributionStopping 

pub type WSLPluginAPI_OnDistributionStopping = Option<unsafe extern "C" fn(Session: *const WSLSessionInformation, Distribution: *const WSLDistributionInformation) -> HRESULT>;
Called when a distribution is about to stop. ‘Session’ and ‘Distribution’ is only valid during while the call is in progress. Note: It’s possible that stopping a distribution fails (for instance if a file is in use). In this case, it’s possible for this notification to be called multiple times for the same distribution.

Aliased Type

pub enum WSLPluginAPI_OnDistributionStopping {
    None,
    Some(unsafe extern "C" fn(*const WSLSessionInformation, *const WSLDistributionInformation) -> i32),
}

Variants

1.0.0

None

No value.

1.0.0

Some(unsafe extern "C" fn(*const WSLSessionInformation, *const WSLDistributionInformation) -> i32)

Some value of type T.